==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/RunAsUserStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RunAsUserStrategyOptionsBuilder extends RunAsUserStrategyOptionsFluentImpl<RunAsUserStrategyOptionsBuilder> implements VisitableBuilder<RunAsUserStrategyOptions,RunAsUserStrategyOptionsBuilder>{
  public RunAsUserStrategyOptionsBuilder() {
    this(false);
  }
  public RunAsUserStrategyOptionsBuilder(Boolean validationEnabled) {
    this(new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withType(instance.getType());
      fluent.withUid(instance.getUid());
      fluent.withUidRangeMax(instance.getUidRangeMax());
      fluent.withUidRangeMin(instance.getUidRangeMin());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance) {
    this(instance,false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withType(instance.getType());
      this.withUid(instance.getUid());
      this.withUidRangeMax(instance.getUidRangeMax());
      this.withUidRangeMin(instance.getUidRangeMin());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  RunAsUserStrategyOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public RunAsUserStrategyOptions build() {
    RunAsUserStrategyOptions buildable = new RunAsUserStrategyOptions(fluent.getType(),fluent.getUid(),fluent.getUidRangeMax(),fluent.getUidRangeMin());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/RunAsUserStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RunAsUserStrategyOptionsBuilder extends RunAsUserStrategyOptionsFluent<RunAsUserStrategyOptionsBuilder> implements VisitableBuilder<RunAsUserStrategyOptions,RunAsUserStrategyOptionsBuilder>{
  public RunAsUserStrategyOptionsBuilder() {
    this(false);
  }
  public RunAsUserStrategyOptionsBuilder(Boolean validationEnabled) {
    this(new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RunAsUserStrategyOptions(), validationEnabled);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptionsFluent<?> fluent,RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new RunAsUserStrategyOptions());

    if (instance != null) {
      fluent.withType(instance.getType());
      fluent.withUid(instance.getUid());
      fluent.withUidRangeMax(instance.getUidRangeMax());
      fluent.withUidRangeMin(instance.getUidRangeMin());
      fluent.withType(instance.getType());
      fluent.withUid(instance.getUid());
      fluent.withUidRangeMax(instance.getUidRangeMax());
      fluent.withUidRangeMin(instance.getUidRangeMin());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance) {
    this(instance,false);
  }
  public RunAsUserStrategyOptionsBuilder(RunAsUserStrategyOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new RunAsUserStrategyOptions());

    if (instance != null) {
      this.withType(instance.getType());
      this.withUid(instance.getUid());
      this.withUidRangeMax(instance.getUidRangeMax());
      this.withUidRangeMin(instance.getUidRangeMin());
      this.withType(instance.getType());
      this.withUid(instance.getUid());
      this.withUidRangeMax(instance.getUidRangeMax());
      this.withUidRangeMin(instance.getUidRangeMin());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  RunAsUserStrategyOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public RunAsUserStrategyOptions build() {
    RunAsUserStrategyOptions buildable = new RunAsUserStrategyOptions(fluent.getType(),fluent.getUid(),fluent.getUidRangeMax(),fluent.getUidRangeMin());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
